==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/entity/ModEntities.java <==
package net.tlotd.entity;

import net.fabricmc.fabric.api.object.builder.v1.entity.FabricEntityTypeBuilder;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_4048;
import net.minecraft.class_7923;
import net.tlotd.TLOTD;
import net.tlotd.entity.custom.InfectedTRexEntity;
import net.tlotd.entity.custom.SeatEntity;
import net.tlotd.entity.custom.TRexEntity;

public class ModEntities {
    public static final class_1299<TRexEntity> TREX = class_2378.method_10230(class_7923.field_41177,
            new class_2960(TLOTD.MOD_ID, "t-rex"),
            FabricEntityTypeBuilder.create(class_1311.field_6294, TRexEntity::new)
                    .dimensions(class_4048.method_18385(3f,5f)).build());

    public static final class_1299<InfectedTRexEntity> INFECTED_TREX = class_2378.method_10230(class_7923.field_41177,
            new class_2960(TLOTD.MOD_ID, "infected_t-rex"),
            FabricEntityTypeBuilder.create(class_1311.field_6294, InfectedTRexEntity::new)
                    .dimensions(class_4048.method_18385(3f,5f)).build());

    public static final class_1299<SeatEntity> SEAT = class_2378.method_10230(class_7923.field_41177,
            new class_2960(TLOTD.MOD_ID, "seat"),
            FabricEntityTypeBuilder.create(class_1311.field_17715, SeatEntity::new)
                    .dimensions(class_4048.method_18385(0.8f,0.5f)).build());

    public static void registerModEntities() {
        TLOTD.LOGGER.info("Registering Entities for " + TLOTD.MOD_ID);
    }

}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/entity/ModEntities.java <==
package net.tlotd.entity;

import net.fabricmc.fabric.api.object.builder.v1.entity.FabricEntityTypeBuilder;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_4048;
import net.minecraft.class_7923;
import net.tlotd.TLOTD;
import net.tlotd.entity.custom.ArmorPiercingArrowEntity;
import net.tlotd.entity.custom.InfectedTRexEntity;
import net.tlotd.entity.custom.SeatEntity;
import net.tlotd.entity.custom.TRexEntity;

public class ModEntities {
    public static final class_1299<TRexEntity> TREX = class_2378.method_10230(class_7923.field_41177,
            new class_2960(TLOTD.MOD_ID, "t-rex"),
            FabricEntityTypeBuilder.create(class_1311.field_6294, TRexEntity::new)
                    .dimensions(class_4048.method_18385(3f,5f)).build());

    public static final class_1299<InfectedTRexEntity> INFECTED_TREX = class_2378.method_10230(class_7923.field_41177,
            new class_2960(TLOTD.MOD_ID, "infected_t-rex"),
            FabricEntityTypeBuilder.create(class_1311.field_6294, InfectedTRexEntity::new)
                    .dimensions(class_4048.method_18385(3f,5f)).build());

    public static final class_1299<SeatEntity> SEAT = class_2378.method_10230(class_7923.field_41177,
            new class_2960(TLOTD.MOD_ID, "seat"),
            FabricEntityTypeBuilder.create(class_1311.field_17715, SeatEntity::new)
                    .dimensions(class_4048.method_18385(0.8f,0.5f)).build());

    public static final class_1299<ArmorPiercingArrowEntity> ARMOR_PIERCING_ARROW =
            class_2378.method_10230(
                    class_7923.field_41177,
                    new class_2960(TLOTD.MOD_ID, "silverthorn_arrow"),
                    FabricEntityTypeBuilder.<ArmorPiercingArrowEntity>create(class_1311.field_17715, ArmorPiercingArrowEntity::new)
                            .dimensions(class_4048.method_18385(0.5f, 0.5f))
                            .trackRangeBlocks(4)
                            .trackedUpdateRate(20)
                            .build()
            );
    public static void registerModEntities() {
        TLOTD.LOGGER.info("Registering Entities for " + TLOTD.MOD_ID);
    }

}
